@@ -5,11 +5,8 @@ import json
 
 
 def __get_schema_from_s3(
-    *,
-    s3_bucket: str,
-    s3_key: str,
-    region_name: str = "us-east-1"
-):
+    s3_bucket, s3_key, region_name='us-east-1'
+) -> dict:
     s3_client = S3(bucket_name=s3_bucket, region_name=region_name)
     obj = s3_client.get_object(s3_path=s3_key)
     obj = obj.read().decode('utf-8')
@@ -18,10 +15,9 @@ def __get_schema_from_s3(
 
 
 def get_schema_from_s3(
-    *,
     s3_path: str,
     region_name: str = "us-east-1"
-):
+)  -> dict:
     if s3_path is None:
         return None
     url = urlparse(s3_path, allow_fragments=False)
